module Console
  module Shell
    def sh(*args)
      puts "> #{args.join(' ')}"
      system(*args)
    end
  end # module Shell

  module Utils
    def seconds_to_human(s)
      s = s.round
      m = (s / 60).floor
      s = s % 60
      h = (m / 60).floor
      m = m % 60
      d = (h / 24).floor
      h = h % 24

      output = "#{s}s"
      output = "#{m}m " + output if m > 0 || h > 0 || d > 0
      output = "#{h}h " + output if h > 0 || d > 0
      output = "#{d}d " + output if d > 0
      output
    end
  end # module Utils

  module Colors
    SEQUENCE = %w(31 32 33 34 35 36 37 31;1 32;1 33;1 34;1 35;1 36;1 37;1)
    # Returns ANSI escaped string.
    #
    def esc_string(esc, text)
      esc + text.to_s + "\e[0m"
    end

    # Returns ANSI escaped string for the colored text.
    #
    def esc_color(color_code, text)
      esc_string "\e[#{color_code}m", text
    end

    # Returns ANSI escaped string for the red colored text.
    #
    def esc_red(text)
      esc_color 31, text
    end

    # Returns ANSI escaped string for the green colored text.
    #
    def esc_green(text)
      esc_color 32, text
    end

    # Returns ANSI escaped string for the yellow colored text.
    #
    def esc_yellow(text)
      esc_color 33, text
    end

    # Returns ANSI escaped string for the blue colored text.
    #
    def esc_blue(text)
      esc_color 34, text
    end

    # Returns ANSI escaped string for the bold text.
    #
    def esc_bold(text)
      esc_string "\e[01;37m", text
    end

    # Returns string padded to given number of characters, text can be escaped.
    #
    def esc_pad(text, num, color = nil)
      esc_text = text
      case color
      when :red, :yellow, :green
        esc_text = send :"esc_#{color}", text
      end
      pad = esc_text.size - text.size
      num > 0 ? ("%-#{num + pad}s" % esc_text) : esc_text
    end

    # Returns string with formatted and padded fields
    # Each arg is an Array:
    # [<text>, [padding_num], [color]]
    #
    def esc_format(*args)
      out = []
      args.each do |arg|
        out << esc_pad(arg[0], arg[1] || 0, arg[2])
      end
      out.join(' ')
    end
  end # module Colors
end # module Console
